note 125297 deleted from class.recursiveiteratoriterator by salathe
| From: | salathe@php.net | Date: | Mon, 24 Aug 2020 12:58:00 +0000 |
| Subject: | note 125297 deleted from class.recursiveiteratoriterator by salathe | ||
| References: | 1 | Groups: | php.notes |
| Request: | Send a blank email to php-notes+get-215016@lists.php.net to get a copy of this message | ||
Note Submitter: N0zzy
----
Some update on the speed of the previous benchmark
from: https://www.php.net/manual/en/class.recursiveiteratoriterator.php#112713
PHP 7.4.5 (cli) (built: Apr 14 2020 16:17:34)
Athlon x3 455 @ 3.1Ghz
RecursiveIteratorIterator: 100 elements -> 0.001 sec
Recursive function : 100 elements -> 0.000 sec
RecursiveIteratorIterator: 1000 elements -> 0.008 sec
Recursive function : 1000 elements -> 0.001 sec
RecursiveIteratorIterator: 10000 elements -> 0.077 sec
Recursive function : 10000 elements -> 0.011 sec
RecursiveIteratorIterator: 100000 elements -> 0.787 sec
Recursive function : 100000 elements -> 0.108 sec
RecursiveIteratorIterator: 1000000 elements -> 7.856 sec
Recursive function : 1000000 elements -> 1.154 sec